@@ -13,8 +13,8 @@ class AgreementOptionInlineAdmin(admin.TabularInline):
 @admin.register(Agreement)
 class AgreementAdmin(admin.ModelAdmin):
     inlines = (AgreementOptionInlineAdmin,)
-    list_display = ('name', 'order')
-    list_editable = ('order',)
+    list_display = ("name", "order")
+    list_editable = ("order",)
     list_filter = (ActiveListFilter,)
 
     def has_delete_permission(self, request, obj=None):
@@ -25,12 +25,11 @@ class AgreementAdmin(admin.ModelAdmin):
 
     def get_actions(self, request):
         actions = super().get_actions(request)
-        if 'delete_selected' in actions:
+        if "delete_selected" in actions:
+
             def delete_selected(model_admin, request, queryset):
                 queryset = queryset.filter(registrations__id=None)
                 return admin.actions.delete_selected(model_admin, request, queryset)
-            actions['delete_selected'] = (
-                delete_selected,
-                *actions['delete_selected'][1:]
-            )
+
+            actions["delete_selected"] = (delete_selected, *actions["delete_selected"][1:])
         return actions
