@@ -1,10 +1,14 @@
+import re
 from collections import namedtuple
 from datetime import date, datetime
+from typing import Any
 
+from django.core.exceptions import ValidationError
 from django.utils.functional import cached_property, lazy
 from django.utils.html import format_html
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
+from schwifty.iban import IBAN
 
 from ..conf import settings
 from ..utils import currency, paragraph
@@ -47,24 +51,24 @@ class PaymentStatusMixin:
     def title(self):
         titles = []
         if self.amount_due and (self.amount_due != self.overdue):
-            titles.append(_('amount due {}').format(currency(self.amount_due)))
+            titles.append(_("amount due {}").format(currency(self.amount_due)))
         if self.overdue:
-            titles.append(_('overdue {}').format(currency(self.overdue)))
+            titles.append(_("overdue {}").format(currency(self.overdue)))
         if self.overpaid:
-            titles.append(_('{} overpaid').format(currency(self.overpaid)))
+            titles.append(_("{} overpaid").format(currency(self.overpaid)))
         if self.balance == 0:
             if self.receivable:
-                titles.append(_('paid'))
+                titles.append(_("paid"))
             else:
-                titles.append(_('payment not requested'))
+                titles.append(_("payment not requested"))
         elif self.balance < 0 and not self.amount_due:  # self.due_from > self.current_date:
-            titles.append(_('payment not requested yet'))
-        return ', '.join(map(str, titles))
+            titles.append(_("payment not requested yet"))
+        return ", ".join(map(str, titles))
 
     def __xrepr__(self):
         return (
-            '{type_name}(price={price}, discount={discount}, paid={paid}, balance={balance}, '
-            'amount_due={amount_due}, overdue={overdue}, overpaid={overpaid})'.format(
+            "{type_name}(price={price}, discount={discount}, paid={paid}, balance={balance}, "
+            "amount_due={amount_due}, overdue={overdue}, overpaid={overpaid})".format(
                 type_name=type(self).__name__,
                 price=self.price,
                 discount=self.discount,
@@ -92,8 +96,8 @@ class PaymentStatusMixin:
 class PaymentStatus(
     PaymentStatusMixin,
     namedtuple(
-        '_PaymentsStatus',
-        ('price', 'discount', 'explanation', 'paid', 'current_date', 'due_from', 'due_date'),
+        "_PaymentsStatus",
+        ("price", "discount", "explanation", "paid", "current_date", "due_from", "due_date"),
     ),
 ):
     @property
@@ -120,45 +124,63 @@ class PaymentStatus(
 class PaymentStatusSum(
     PaymentStatusMixin,
     namedtuple(
-        '_PaymentsStatusSum',
-        ('price', 'discount', 'paid', 'amount_due', 'overdue', 'overpaid'),
+        "_PaymentsStatusSum",
+        ("price", "discount", "paid", "amount_due", "overdue", "overpaid"),
     ),
 ):
     pass
 
 
-class BankAccount:
-    def __init__(self, iban):
-        self.iban = iban
+class BankAccount(IBAN):
+    czech_bban_regex = re.compile(r"(([0-9]{1,6})\s?-\s?)?([0-9]{1,10})\s?/\s?([0-9]{4})")
 
-    @cached_property
-    def country_code(self):
-        return self.iban[:2]
-
-    @cached_property
-    def bank_code(self):
-        return self.iban[4:8]
+    def __init__(self, bank_account: str):
+        match = self.czech_bban_regex.match(bank_account)
+        if match:
+            x, prefix, account, bank_code = match.groups()
+            account_code = (prefix or "").zfill(6) + account.zfill(10)
+            bank_account = f"CZ??{bank_code}{account_code}"
+        super().__init__(bank_account)
 
     @cached_property
     def account_prefix(self):
-        return self.iban[8:14].lstrip('0')
+        return self.account_code[:6].lstrip("0")
 
     @cached_property
     def account_number(self):
-        return self.iban[14:].lstrip('0')
+        return self.account_code[6:].lstrip("0")
 
     def __str__(self):
-        return '%s%s%s/%s' % (
-            self.account_prefix,
-            self.account_prefix and '-',
-            self.account_number,
-            self.bank_code,
+        if self.country_code == "CZ":
+            return "%s%s%s/%s" % (
+                self.account_prefix,
+                self.account_prefix and "-",
+                self.account_number,
+                self.bank_code,
+            )
+        else:
+            return self.formatted
+
+
+def parse_bank_account(bank_account: Any) -> BankAccount:
+    if isinstance(bank_account, BankAccount):
+        return bank_account
+    if isinstance(bank_account, IBAN):
+        return BankAccount(bank_account.compact)
+    if not isinstance(bank_account, str):
+        bank_account = str(bank_account)
+    try:
+        return BankAccount(bank_account)
+    except ValueError:
+        raise ValidationError(
+            message=_("Enter a valid account number."),
+            code="invalid",
         )
 
 
 def generate_variable_symbol(registration):
     # get base variable symol from the configured expression
-    variable_symbol = eval(settings.LEPRIKON_VARIABLE_SYMBOL_EXPRESSION, {'reg': registration})
+    variable_symbol = eval(settings.LEPRIKON_VARIABLE_SYMBOL_EXPRESSION, {"reg": registration})
 
     # add check digit
     odd_sum = 0
@@ -173,25 +195,27 @@ def generate_variable_symbol(registration):
 
 
 def help_text_with_html_default(help_text, html_default):
-    keep_empty = paragraph(_('Keep empty to use default value:'))
-    return mark_safe('{}{}{}'.format(
-        paragraph(help_text),
-        keep_empty,
-        html_default,
-    ) if help_text else '{}{}'.format(
-        keep_empty,
-        html_default,
-    ))
+    keep_empty = paragraph(_("Keep empty to use default value:"))
+    return mark_safe(
+        "{}{}{}".format(
+            paragraph(help_text),
+            keep_empty,
+            html_default,
+        )
+        if help_text
+        else "{}{}".format(
+            keep_empty,
+            html_default,
+        )
+    )
 
 
 lazy_help_text_with_html_default = lazy(help_text_with_html_default, str)
 
 
 def help_text_with_default(help_text, default):
-    keep_empty_default = _('Keep empty to use default value: {}').format(default)
-    return paragraph(
-        '{}\n\n{}'.format(help_text, keep_empty_default) if help_text else keep_empty_default
-    )
+    keep_empty_default = _("Keep empty to use default value: {}").format(default)
+    return paragraph("{}\n\n{}".format(help_text, keep_empty_default) if help_text else keep_empty_default)
 
 
 lazy_help_text_with_default = lazy(help_text_with_default, str)
@@ -210,3 +234,10 @@ def change_year(d, year_delta):
         except ValueError:
             # handle leap-year
             return datetime(d.year + year_delta, d.month, d.day - 1, d.hour, d.minute, d.second)
+
+
+def shorten(string, length):
+    if len(string) <= length:
+        return string
+    half = length // 2 - 1
+    return f"{string[:half]}...{string[half + 3 - length:]}"
