@@ -22,18 +22,18 @@ from django.contrib.sites.models import Site
 
 try:
     urlpatterns = [
-        url(r'^admin/', include(admin.site.urls)),
-        url(r'^pays/', include('django_pays.urls')),
-        url(r'^social/', include('social_django.urls')),
-        url(r'^verified-email-field/', include('verified_email_field.urls')),
-        url(r'^', include('cms.urls')),
+        url(r"^admin/", include(admin.site.urls)),
+        url(r"^pays/", include("django_pays.urls")),
+        url(r"^social/", include("social_django.urls")),
+        url(r"^verified-email-field/", include("verified_email_field.urls")),
+        url(r"^", include("cms.urls")),
         # this won't work for displaying pages,
         # but allows reverse resolving before leprikon apphook is attached to any page
-        url(r'^leprikon', include('leprikon.urls')),
+        url(r"^leprikon", include("leprikon.urls")),
     ]
 except Site.DoesNotExist:
     # this may happen during data migration
-    print('Failed to load urls, because there is no Site.')
+    print("Failed to load urls, because there is no Site.")
     urlpatterns = []
 
 if settings.DEBUG:
