@@ -4,16 +4,32 @@ from django.views.decorators.csrf import csrf_exempt
 
 from ..conf import settings
 from . import (
-    billing_info, journals, leaders, messages, parents, participants,
-    registrationlink, registrations, reports, schoolyear, subjects, summaries,
-    terms_conditions, timesheets, user,
+    billing_info,
+    donation,
+    journals,
+    leaders,
+    messages,
+    parents,
+    participants,
+    refundrequest,
+    registrationlink,
+    registrations,
+    reports,
+    schoolyear,
+    subjects,
+    summaries,
+    terms_conditions,
+    timesheets,
+    user,
 )
 from .reports import (
-    courses as reports_courses, debtors as reports_debtors,
-    events as reports_events, orderables as reports_orderables,
+    courses as reports_courses,
+    debtors as reports_debtors,
+    events as reports_events,
+    orderables as reports_orderables,
 )
 
-login_url = reverse('leprikon:user_login')
+login_url = reverse("leprikon:user_login")
 
 
 def _user_is_leader(u):
@@ -72,7 +88,16 @@ registration_link = registrationlink.RegistrationLinkView.as_view()
 registration_link_form = login_required(registrationlink.RegistrationLinkFormView.as_view())
 
 payment_list = login_required(subjects.SubjectPaymentsListView.as_view())
-payment_pdf = login_required(subjects.SubjectPaymentPdfView.as_view())
+received_payment_pdf = login_required(subjects.SubjectReceivedPaymentPdfView.as_view())
+returned_payment_pdf = login_required(subjects.SubjectReturnedPaymentPdfView.as_view())
+
+refund_request_create = login_required(refundrequest.RefundRequestCreateView.as_view())
+refund_request_update = login_required(refundrequest.RefundRequestUpdateView.as_view())
+refund_request_delete = login_required(refundrequest.RefundRequestDeleteView.as_view())
+payment_transfer_create = login_required(refundrequest.PaymentTransferCreateView.as_view())
+donation_create = login_required(refundrequest.DonationCreateView.as_view())
+donation_list = login_required(donation.DonationListView.as_view())
+donation_pdf = login_required(donation.DonationPdfView.as_view())
 
 participant_list = login_required(participants.ParticipantListView.as_view())
 participant_create = login_required(participants.ParticipantCreateView.as_view())
